@@ -48,6 +48,12 @@ class TestURLs(TestCase):
             url='/register',
             url_name='user_management_api:register')
 
+    def test_profile_avatar_url(self):
+        self.check_url(
+            view_name='ProfileAvatar',
+            url='/profile/avatar',
+            url_name='user_management_api:profile_avatar')
+
     def test_user_detail_url(self):
         self.check_url(
             view_name='UserDetail',
@@ -55,6 +61,13 @@ class TestURLs(TestCase):
             url_name='user_management_api:user_detail',
             url_kwargs={'pk': 1})
 
+    def test_user_avatar_url(self):
+        self.check_url(
+            view_name='UserAvatar',
+            url='/users/1/avatar',
+            url_name='user_management_api:user_avatar',
+            url_kwargs={'pk': 1})
+
     def test_user_list_url(self):
         self.check_url(
             view_name='UserList',
