@@ -5,8 +5,10 @@ urlpatterns = patterns('',
     url(r'', include(
         patterns('',
             url(r'', include('user_management.api.urls')),
-            url(r'', include('user_management.api.urls.users')),
+            url(r'', include('user_management.api.urls.profile_avatar')),
             url(r'', include('user_management.api.urls.verify_email')),
+            url(r'', include('user_management.api.urls.users')),
+            url(r'', include('user_management.api.urls.user_avatar')),
         ),
         namespace='user_management_api'
     ))
